==> texlive-base_2021.20220204.orig.tar.xz: texlive-base-2021.20220204/texmf-dist/tex/luatex/minim-pdf/minim-languagecodes.lua <==

-- Associating language codes with language names used with \uselanguage.

return {
    afrikaans            = 'af',
    akkadian             = 'akk',
    american             = 'en-US',
    amharic              = 'am',
    ancientgreek         = 'grc',
    arabic               = 'ar',
    aramaic              = 'arc',
    armenian             = 'hy',
    assamese             = 'as',
    avestan              = 'ae',
    basque               = 'eu',
    belarusian           = 'be',
    bengali              = 'bn',
    biblicalhebrew       = 'hbo',
    bohairic             = 'cop-x-bohairic',
    bokmal               = 'nb',
    bosnian              = 'bs',
    brazilian            = 'pt-BR',
    breton               = 'br',
    british              = 'en-UK',
    bulgarian            = 'bg',
    burmese              = 'my',
    byzantine            = 'gkm',
    cantonese            = 'yue',
    catalan              = 'ca',
    chechen              = 'ce',
    cherokee             = 'chr',
    chinese              = 'zh',
    churchlatin          = 'la-x-liturgic',
    churchslavonic       = 'cu',
    classiclatin         = 'la-x-classic',
    classictibetan       = 'xtc',
    coptic               = 'cop',
    croatian             = 'hr',
    czech                = 'cs',
    danish               = 'da',
    dari                 = 'prs',
    dutch                = 'nl',
    english              = 'en',
    espanol              = 'es',
    esperanto            = 'eo',
    estonian             = 'et',
    ethiopic             = 'mul-ethi',
    etruscan             = 'ett',
    farsi                = 'fa',
    finnish              = 'fi',
    flemish              = 'nl-BE',
    francais             = 'fr',
    french               = 'fr',
    frisian              = 'fy',
    friulan              = 'fur',
    galician             = 'gl',
    geez                 = 'gez',
    georgian             = 'ka',
    german               = 'de',
    ['german-x-latest']  = 'de',
    gothic               = 'got',
    greek                = 'el',
    gujarati             = 'gu',
    hebrew               = 'he',
    hindi                = 'hi',
    hittite              = 'hit',
    hungarian            = 'hu',
    icelandic            = 'is',
    indonesian           = 'id',
    interlingua          = 'ia',
    irish                = 'ga',
    italian              = 'it',
    japanese             = 'ja',
    kannada              = 'kn',
    koine                = 'grc-x-koine',
    kurmanji             = 'kmr',
    latin                = 'la',
    latvian              = 'lv',
    lithuanian           = 'lt',
    liturgicallatin      = 'la-x-liturgic',
    malayalam            = 'ml',
    marathi              = 'mr',
    medievalgreek        = 'gkm',
    medievallatin        = 'la-x-medieval',
    mongolian            = 'mn-cyrl',
    mongolianlmc         = 'mn-cyrl-x-lmc',
    monogreek            = 'el-monoton',
    multiple             = 'mul',
    ngerman              = 'de-1996',
    ['ngerman-x-latest'] = 'de-1996',
    nohyph               = 'und',
    nolang               = 'zxx',
    norsk                = 'nb',
    norwegian            = 'nb',
    nynorsk              = 'nn',
    occitan              = 'oc',
    oriya                = 'or',
    pali                 = 'pi',
    patois               = 'fr',
    persian              = 'fa',
    piedmontese          = 'pms',
    pinyin               = 'zh-latn-pinyin',
    polish               = 'pl',
    polygreek            = 'el-polyton',
    portuges             = 'pt',
    portuguese           = 'pt',
    punjabi              = 'pa',
    romanian             = 'ro',
    romansh              = 'rm',
    russian              = 'ru',
    sahidic              = 'cop-x-sahidic',
    samaritan            = 'smp',
    sanskrit             = 'sa',
    serbian              = 'sr-latn',
    serbianc             = 'sr-cyrl',
    slovak               = 'sk',
    slovene              = 'sl',
    slovenian            = 'sl',
    spanish              = 'es',
    sumerian             = 'sux',
    swedish              = 'sv',
    swissgerman          = 'de-CH',
    syriac               = 'syr',
    talmudic             = 'tmr',
    tamil                = 'ta',
    telugu               = 'te',
    thai                 = 'th',
    tibetan              = 'bo',
    turkish              = 'tr',
    turkmen              = 'tk',
    ugaritic             = 'uga',
    uncoded              = 'mis',
    undetermined         = 'und',
    ukenglish            = 'en-UK',
    UKenglish            = 'en-UK',
    ukrainian            = 'uk',
    uppersorbian         = 'hsb',
    usenglish            = 'en-US',
    USenglish            = 'en-US',
    usenglishmax         = 'en-US',
    vedic                = 'sa-vaidika',
    walloon              = 'wa',
    welsh                = 'cy',
    yiddish              = 'yi',
}

==> texlive-base_2025.20250927.orig.tar.xz: texlive-base-2025.20250927/texmf-dist/tex/luatex/minim-pdf/minim-languagecodes.lua <==

-- Associating language codes with language names used with \uselanguage.

return {
    afrikaans            = 'af',
    akkadian             = 'akk',
    american             = 'en-US',
    amharic              = 'am',
    ancientgreek         = 'grc',
    arabic               = 'ar',
    aramaic              = 'arc',
    armenian             = 'hy',
    assamese             = 'as',
    avestan              = 'ae',
    basque               = 'eu',
    belarusian           = 'be',
    bengali              = 'bn',
    biblicalhebrew       = 'hbo',
    bohairic             = 'cop-x-bohairic',
    bokmal               = 'nb',
    bosnian              = 'bs',
    brazilian            = 'pt-BR',
    breton               = 'br',
    british              = 'en-UK',
    bulgarian            = 'bg',
    burmese              = 'my',
    byzantine            = 'gkm',
    cantonese            = 'yue',
    catalan              = 'ca',
    chechen              = 'ce',
    cherokee             = 'chr',
    chinese              = 'zh',
    churchlatin          = 'la-x-liturgic',
    churchslavonic       = 'cu',
    classiclatin         = 'la-x-classic',
    classictibetan       = 'xtc',
    coptic               = 'cop',
    croatian             = 'hr',
    czech                = 'cs',
    danish               = 'da',
    dari                 = 'prs',
    dutch                = 'nl',
    english              = 'en',
    espanol              = 'es',
    esperanto            = 'eo',
    estonian             = 'et',
    ethiopic             = 'mul-ethi',
    etruscan             = 'ett',
    farsi                = 'fa',
    finnish              = 'fi',
    flemish              = 'nl-BE',
    francais             = 'fr',
    french               = 'fr',
    frisian              = 'fy',
    friulan              = 'fur',
    galician             = 'gl',
    geez                 = 'gez',
    georgian             = 'ka',
    german               = 'de',
    ['german-x-latest']  = 'de',
    gothic               = 'got',
    greek                = 'el',
    gujarati             = 'gu',
    hebrew               = 'he',
    hindi                = 'hi',
    hittite              = 'hit',
    hungarian            = 'hu',
    icelandic            = 'is',
    indonesian           = 'id',
    interlingua          = 'ia',
    irish                = 'ga',
    italian              = 'it',
    japanese             = 'ja',
    kannada              = 'kn',
    koine                = 'grc-x-koine',
    kurmanji             = 'kmr',
    latin                = 'la',
    latvian              = 'lv',
    lithuanian           = 'lt',
    liturgicallatin      = 'la-x-liturgic',
    macedonian           = 'mk',
    malayalam            = 'ml',
    marathi              = 'mr',
    medievalgreek        = 'gkm',
    medievallatin        = 'la-x-medieval',
    mongolian            = 'mn-cyrl',
    mongolianlmc         = 'mn-cyrl-x-lmc',
    monogreek            = 'el-monoton',
    multiple             = 'mul',
    ngerman              = 'de-1996',
    ['ngerman-x-latest'] = 'de-1996',
    nohyph               = 'und',
    nolang               = 'zxx',
    norsk                = 'nb',
    norwegian            = 'nb',
    nynorsk              = 'nn',
    occitan              = 'oc',
    oldgerman            = 'de',
    oriya                = 'or',
    pali                 = 'pi',
    panjabi              = 'pa',
    patois               = 'fr',
    persian              = 'fa',
    piedmontese          = 'pms',
    pinyin               = 'zh-latn-pinyin',
    polish               = 'pl',
    polygreek            = 'el-polyton',
    portuges             = 'pt',
    portuguese           = 'pt',
    punjabi              = 'pa',
    romanian             = 'ro',
    romansh              = 'rm',
    russian              = 'ru',
    sahidic              = 'cop-x-sahidic',
    samaritan            = 'smp',
    sanskrit             = 'sa',
    schoolfinnish        = 'fi',
    serbian              = 'sr-latn',
    serbianc             = 'sr-cyrl',
    slovak               = 'sk',
    slovene              = 'sl',
    slovenian            = 'sl',
    spanish              = 'es',
    sumerian             = 'sux',
    swedish              = 'sv',
    swissgerman          = 'de-CH',
    syriac               = 'syr',
    talmudic             = 'tmr',
    tamil                = 'ta',
    telugu               = 'te',
    thai                 = 'th',
    tibetan              = 'bo',
    turkish              = 'tr',
    turkmen              = 'tk',
    ugaritic             = 'uga',
    ukenglish            = 'en-UK',
    UKenglish            = 'en-UK',
    ukrainian            = 'uk',
    uncoded              = 'mis',
    undetermined         = 'und',
    uppersorbian         = 'hsb',
    usenglish            = 'en-US',
    USenglish            = 'en-US',
    usenglishmax         = 'en-US',
    vedic                = 'sa-vaidika',
    walloon              = 'wa',
    welsh                = 'cy',
    yiddish              = 'yi',
}
